from setuptools import setup


setup(
    use_scm_version={
        "write_to": "mc_goods/_version.py",
        "write_to_template": '__version__ = "{version}"',
        "tag_regex": r"^(?P<prefix>v)?(?P<version>[^\+]+)(?P<suffix>.*)?$",
    },
    entry_points={
        'intake.catalogs': [
            'mc_CBOFS_RGRID = mc_goods:cbofs_rgrid',
            'mc_CBOFS = mc_goods:cbofs',
            'mc_CIOFS_RGRID = mc_goods:ciofs_rgrid',
            'mc_CIOFS = mc_goods:ciofs',
            'mc_CREOFS_RGRID = mc_goods:creofs_rgrid',
            'mc_CREOFS = mc_goods:creofs',
            'mc_DBOFS_RGRID = mc_goods:dbofs_rgrid',
            'mc_DBOFS = mc_goods:dbofs',
            'mc_GFS_1_2DEG = mc_goods:gfs_1_2deg',
            'mc_GFS_1_4DEG = mc_goods:gfs_1_4deg',
            'mc_GFS_1DEG = mc_goods:gfs_1deg',
            'mc_GOFS = mc_goods:gofs',
            'mc_GOMOFS_2DS = mc_goods:gomofs_2ds',
            'mc_GOMOFS_RGRID = mc_goods:gomofs_rgrid',
            'mc_GOMOFS = mc_goods:gomofs',
            'mc_LEOFS_RGRID = mc_goods:leofs_rgrid',
            'mc_LEOFS = mc_goods:leofs',
            'mc_LMHOFS_RGRID = mc_goods:lmhofs_rgrid',
            'mc_LMHOFS = mc_goods:lmhofs',
            'mc_LOOFS_FVCOM = mc_goods:loofs_fvcom',
            'mc_LOOFS = mc_goods:loofs',
            'mc_LSOFS_FVCOM = mc_goods:lsofs_fvcom',
            'mc_LSOFS = mc_goods:lsofs',
            'mc_NGOFS2_2DS = mc_goods:ngofs2_2ds',
            'mc_NGOFS2_RGRID = mc_goods:ngofs2_rgrid',
            'mc_NGOFS2 = mc_goods:ngofs2',
            'mc_NYOFS = mc_goods:nyofs',
            'mc_RTOFS_2D = mc_goods:rtofs_2d',
            'mc_RTOFS_AK = mc_goods:rtofs_ak',
            'mc_RTOFS_EAST = mc_goods:rtofs_east',
            'mc_RTOFS_WEST = mc_goods:rtofs_west',
            'mc_RTOFS = mc_goods:rtofs',
            'mc_SFBOFS_RGRID = mc_goods:sfbofs_rgrid',
            'mc_SFBOFS = mc_goods:sfbofs',
            'mc_TBOFS_RGRID = mc_goods:tbofs_rgrid',
            'mc_TBOFS = mc_goods:tbofs',
            'mc_WCOFS_2DS = mc_goods:wcofs_2ds',
            'mc_WCOFS_RGRID = mc_goods:wcofs_rgrid',
            'mc_WCOFS = mc_goods:wcofs',
        ]
    },
)



"""
mc-goods: `model_catalogs` catalogs for NOAA GOODS.
"""


from importlib.metadata import PackageNotFoundError, version


try:
    __version__ = version("mc-nwgoa")
except PackageNotFoundError:
    # package is not installed
    pass


import intake
import os
here = os.path.abspath(os.path.dirname(__file__))


# after installation, these will be available as e.g. intake.cat.cbofs, with its sources

cbofs_rgrid = intake.open_catalog(os.path.join(here, 'cbofs-rgrid.yaml'), ttl=None)
cbofs = intake.open_catalog(os.path.join(here, 'cbofs.yaml'), ttl=None)
ciofs_rgrid = intake.open_catalog(os.path.join(here, 'ciofs-rgrid.yaml'), ttl=None)
ciofs = intake.open_catalog(os.path.join(here, 'ciofs.yaml'), ttl=None)
creofs_rgrid = intake.open_catalog(os.path.join(here, 'creofs-rgrid.yaml'), ttl=None)
creofs = intake.open_catalog(os.path.join(here, 'creofs.yaml'), ttl=None)
dbofs_rgrid = intake.open_catalog(os.path.join(here, 'dbofs-rgrid.yaml'), ttl=None)
dbofs = intake.open_catalog(os.path.join(here, 'dbofs.yaml'), ttl=None)
gfs_1_2deg = intake.open_catalog(os.path.join(here, 'gfs-1-2deg.yaml'), ttl=None)
gfs_1_4deg = intake.open_catalog(os.path.join(here, 'gfs-1-4deg.yaml'), ttl=None)
gfs_1deg = intake.open_catalog(os.path.join(here, 'gfs-1deg.yaml'), ttl=None)
gofs = intake.open_catalog(os.path.join(here, 'gofs.yaml'), ttl=None)
gomofs_2ds = intake.open_catalog(os.path.join(here, 'gomofs-2ds.yaml'), ttl=None)
gomofs_rgrid = intake.open_catalog(os.path.join(here, 'gomofs-rgrid.yaml'), ttl=None)
gomofs = intake.open_catalog(os.path.join(here, 'gomofs.yaml'), ttl=None)
leofs_rgrid = intake.open_catalog(os.path.join(here, 'leofs-rgrid.yaml'), ttl=None)
leofs = intake.open_catalog(os.path.join(here, 'leofs.yaml'), ttl=None)
lmhofs_rgrid = intake.open_catalog(os.path.join(here, 'lmhofs-rgrid.yaml'), ttl=None)
lmhofs = intake.open_catalog(os.path.join(here, 'lmhofs.yaml'), ttl=None)
loofs_fvcom = intake.open_catalog(os.path.join(here, 'loofs-fvcom.yaml'), ttl=None)
loofs = intake.open_catalog(os.path.join(here, 'loofs.yaml'), ttl=None)
lsofs_fvcom = intake.open_catalog(os.path.join(here, 'lsofs-fvcom.yaml'), ttl=None)
lsofs = intake.open_catalog(os.path.join(here, 'lsofs.yaml'), ttl=None)
ngofs2_2ds = intake.open_catalog(os.path.join(here, 'ngofs2-2ds.yaml'), ttl=None)
ngofs2_rgrid = intake.open_catalog(os.path.join(here, 'ngofs2-rgrid.yaml'), ttl=None)
ngofs2 = intake.open_catalog(os.path.join(here, 'ngofs2.yaml'), ttl=None)
nyofs = intake.open_catalog(os.path.join(here, 'nyofs.yaml'), ttl=None)
rtofs_2d = intake.open_catalog(os.path.join(here, 'rtofs-2d.yaml'), ttl=None)
rtofs_ak = intake.open_catalog(os.path.join(here, 'rtofs-ak.yaml'), ttl=None)
rtofs_east = intake.open_catalog(os.path.join(here, 'rtofs-east.yaml'), ttl=None)
rtofs_west = intake.open_catalog(os.path.join(here, 'rtofs-west.yaml'), ttl=None)
rtofs = intake.open_catalog(os.path.join(here, 'rtofs.yaml'), ttl=None)
sfbofs_rgrid = intake.open_catalog(os.path.join(here, 'sfbofs-rgrid.yaml'), ttl=None)
sfbofs = intake.open_catalog(os.path.join(here, 'sfbofs.yaml'), ttl=None)
tbofs_rgrid = intake.open_catalog(os.path.join(here, 'tbofs-rgrid.yaml'), ttl=None)
tbofs = intake.open_catalog(os.path.join(here, 'tbofs.yaml'), ttl=None)
wcofs_2ds = intake.open_catalog(os.path.join(here, 'wcofs-2ds.yaml'), ttl=None)
wcofs_rgrid = intake.open_catalog(os.path.join(here, 'wcofs-rgrid.yaml'), ttl=None)
wcofs = intake.open_catalog(os.path.join(here, 'wcofs.yaml'), ttl=None)
